@@ -88,7 +88,9 @@ def get_investment_pages(pdf_bytes):
         tmp.write(pdf_bytes)
 
         pg_count = PdfFileReader(tmp.name).numPages
-        pages = convert_from_path(tmp.name)
+        pages = convert_from_path(
+            tmp.name, thread_count=10, fmt="jpg", dpi=300
+        )
         if pg_count == "6":
             return pages[:3], pages[3:-2], pages[-2]
         cv_image = np.array(pages[3])
@@ -298,15 +300,15 @@ def process_page(page, row_count, results, pg_count):
 
 
 def extract_now(results, k, row, row_index, columns, pg_count):
-    """
+    """Extract from investments of judicial watch documents
 
-    :param results:
-    :param k:
-    :param row:
-    :param row_index:
-    :param columns:
-    :param pg_count:
-    :return:
+    :param results: Our current extraction results
+    :param k: The section
+    :param row: the Row we are extracting
+    :param row_index: the row count
+    :param columns: The available columns
+    :param pg_count: The page extraction is on
+    :return: Extracted content from row
     """
 
     sema.acquire()
@@ -318,6 +320,12 @@ def extract_now(results, k, row, row_index, columns, pg_count):
         color_coverted = cv2.cvtColor(item, cv2.COLOR_BGR2RGB)
         pil_image = Image.fromarray(color_coverted)
         t = ocr_slice(pil_image, i)
+        if "description" in t.lower() or "assets" in t.lower():
+            # If this is a bad PDF we may extract from the addendum.
+            # Check if we found it and move along.  Otherwise it could be
+            # Bleed over from one page
+            return results
+
         results["sections"][k]["rows"][row_index][column] = {
             "text": clean_stock_names(t),
             "is_redacted": find_redactions(pil_image),
@@ -333,8 +341,8 @@ def extract_section_VII(
     investment_pages: List,
     threaded: bool,
     pg_count: int,
-):
-    """
+) -> Dict:
+    """Extract content from investment pages on judicial watch documents
 
     :param results:
     :param investment_pages:
@@ -362,6 +370,11 @@ def extract_section_VII(
                     results, k, row, row_index, columns, pg_count
                 )
             row_index += 1
+        # Occasionally the judicial watch documents have multiple documents
+        # appended to them.  In this case, we stop processing after we
+        # no longer detect multiple rows to process
+        if len(data) < 5:
+            break
     for thread in threads:
         thread.join()
 
@@ -378,7 +391,7 @@ def process_addendum(addendum_page) -> Dict:
     slice = addendum_page.crop(
         (
             0,
-            height * 0.15,
+            height * 0.1,
             width,
             height * 0.95,
         )
@@ -406,6 +419,7 @@ def extract_page(page: Image) -> List[List]:
     _, _, processed_image = box_extraction(page)
 
     data = []
+    colors = set()
     first_key = None
     for row in processed_image:
         if first_key == None:
@@ -430,6 +444,7 @@ def extract_page(page: Image) -> List[List]:
                 current_x, last_x, last_x_hit = 0, 0, 0
                 for vertical_slice in vertical_slices:
                     current_x += 1
+                    colors.add(sum(vertical_slice))
                     if sum(vertical_slice) < 1000:
                         if abs(current_x - last_x) > 2:
                             if last_x_hit > 25:
@@ -447,4 +462,52 @@ def extract_page(page: Image) -> List[List]:
                     data.append(s8)
                 last_y_hit = current_y
             last_y = current_y
+
+    # Check with this xnumber
+    xnumber = sorted(list(colors))[30]
+    if len(data) < 5:
+        current_y, last_y, last_y_hit = 0, 0, 0
+        data = []
+        first_key = None
+        for row in processed_image:
+            if first_key == None:
+                first_key = sum(row)
+            current_y += 1
+
+            if ((float(sum(row)) / first_key)) * 100 < 25:
+                if abs(current_y - last_y) > 2:
+                    horizontal_slice = processed_image[
+                        last_y_hit:current_y, 0:max_x
+                    ]
+                    horizontal_slice = cv2.cvtColor(
+                        horizontal_slice, cv2.COLOR_GRAY2BGR
+                    )
+                    h, _, _ = horizontal_slice.shape
+                    vertical_slices = [
+                        horizontal_slice[:, x, y]
+                        for x in range(max_x)
+                        for y in range(1)
+                    ]
+                    s8 = []
+                    current_x, last_x, last_x_hit = 0, 0, 0
+                    for vertical_slice in vertical_slices:
+                        current_x += 1
+                        if sum(vertical_slice) < xnumber:
+                            if abs(current_x - last_x) > 2:
+                                if last_x_hit > 25:
+                                    s8.append(
+                                        open_cv_image[
+                                            last_y_hit:current_y,
+                                            last_x_hit:current_x,
+                                        ]
+                                    )
+                                last_x_hit = current_x
+                            last_x = current_x
+                    if len(s8) >= 10:
+                        if len(s8) == 11:
+                            s8 = s8[1:]
+                        data.append(s8)
+                    last_y_hit = current_y
+                last_y = current_y
+
     return data
